@@ -8,7 +8,7 @@ use base 'Spreadsheet::Engine::Function::series';
 sub calculate {
   return sub {
     my ($in, $total) = @_;
-    return $total + $in->{value};
+    return $total + $in->value;
   };
 }
 
@@ -51,7 +51,7 @@ All Rights Reserved.
 Portions (c) Copyright 2007 Socialtext, Inc.
 All Rights Reserved.
 
-Portions (c) Copyright 2007 Tony Bowden
+Portions (c) Copyright 2007, 2008 Tony Bowden
 
 =head1 LICENCE
 
